SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
/*
	-- Archive/Restore  range of dates
	exec dbo.MoveToArchive 0,'2009-10-29' , '2009-11-01' 
	exec dbo.MoveFromArchive 0,'2009-10-29' , '2009-11-01' 
    
    -- Archive/Restore  all database content
	exec dbo.MoveToArchive 1
	exec dbo.MoveFromArchive 1

*/


--  Object: create Db
CREATE DATABASE [ObserveIT_Archive]
GO


use [ObserveIT_Archive]
GO

/*** Object:    Create archived tables               ********************************************/
--0) [ServerInvatory]
CREATE TABLE [dbo].[ServerInvatory]
(
	[SrvID] [uniqueidentifier]PRIMARY KEY,
	[SrvName] [varchar](50) NOT NULL,
	[SrvDateTime] [datetime] NOT NULL,
	[SrvVersion] [nvarchar](40) NULL,
	[SrvConfigurationStatus] [smallint] NOT NULL ,
	[SrvMonitorStatus] [smallint] NOT NULL ,
	[EncryptionKeyId] [uniqueidentifier] NOT NULL ,
	[MetaDataHash] [varchar](80) NULL,
	[GroupPolicyId] [uniqueidentifier] NOT NULL,
	[MetaDataHashByLicense] [nvarchar](80) NULL,
	[AgentType] [int] NULL
) ON [PRIMARY]


--1)[ScreenshotsSessions]
CREATE TABLE [dbo].[ScreenshotsSessions]
(
	[SessionID] [uniqueidentifier] NOT NULL PRIMARY KEY,
	[SrvID] [uniqueidentifier] NOT NULL,
	[LoginName] [varchar](50) NOT NULL,
	[DomainName] [varchar](50) NOT NULL,
	[MachineName] [varchar](50) NOT NULL,
	[SessionDate] [datetime] NOT NULL,
	[ClientAddress] [nvarchar](25) NULL,
	[ClientName] [nvarchar](50) NULL,
	[Trim] [int] NULL ,
	[ExtSlides] [int] NOT NULL ,
	[SessionLastActivityDate] [datetime] NOT NULL,
	[IsAlive] [bit] NULL 
) ON [PRIMARY]

GO

--2)[SessionDetails]
CREATE TABLE [dbo].[SessionDetails]
(
	[SDID] [uniqueidentifier] PRIMARY KEY ,
	[SessionID] [uniqueidentifier] NOT NULL,
	[UserName] [nvarchar](50) NOT NULL,
	[Category] [int] NOT NULL ,
	[Description] [nvarchar](500) NOT NULL ,
	[SessionDate] [datetime] NOT NULL,
	[WebCastID] [uniqueidentifier] NOT NULL ,
	[WebCastName] [nvarchar](250) NULL,
	[UserAuthentication] [nvarchar](100) NOT NULL
) ON [PRIMARY]

GO

--3)[SessionProcesses]
CREATE TABLE [dbo].[SessionProcesses]
(
	[SessionId] [uniqueidentifier] NOT NULL,
	[ProcessName] [varchar](256) NOT NULL,
	[ApplicationName] [nvarchar](256) NULL,
	CONSTRAINT [PK_SessionProcesses] PRIMARY KEY CLUSTERED 
	(
		[SessionId] ASC,
		[ProcessName] ASC
	) ON [PRIMARY]
) ON [PRIMARY]

GO

--4)[SessionProcessWindowTitles]
CREATE TABLE [dbo].[SessionProcessWindowTitles]
(
	[SessionId] [uniqueidentifier] NOT NULL,
	[ProcessName] [varchar](256) NOT NULL,
	[WindowTitle] [nvarchar](256) NOT NULL,
	[ApplicationName] [nvarchar](256) NULL,
	[FirstScreenshotId] [uniqueidentifier] NOT NULL ,
	[FirstScreenshotTime] [datetime] NULL,
	CONSTRAINT [PK_SessionProcessWindowTitles] PRIMARY KEY CLUSTERED 
	(
		[SessionId] ASC,
		[ProcessName] ASC,
		[WindowTitle] ASC
	) ON [PRIMARY]
) ON [PRIMARY]
GO


--5)[ClientSessionLog]
CREATE TABLE [dbo].[ClientSessionLog]
(
	[SessionId] [uniqueidentifier]  PRIMARY KEY,
	[ServerId] [uniqueidentifier] NULL,
	[MachineName] [varchar](50) NULL,
	[LoginName] [varchar](50)  NULL,
	[DomainName] [varchar](50) NULL,
	[CreatedDate] [datetime] NOT NULL ,
	[Status] [smallint] NOT NULL
) ON [PRIMARY]

GO

--6)[AuditLogSessions]
CREATE TABLE [dbo].[AuditLogSessions]
(
	[AuditLogSessionId] [int] PRIMARY KEY,
	[AuditLogId] [int] NULL,
	[AccessedDate] [datetime] NOT NULL ,
	[SessionId] [uniqueidentifier] NULL,
	[SessionLoginName] [varchar](50) NULL,
	[SessionDate] [datetime] NULL,
	[SessionServerName] [varchar](50) NULL
)ON [PRIMARY]
GO

--7)[Casts]
CREATE TABLE [dbo].[Casts]
(
	[CastID] [uniqueidentifier] PRIMARY KEY,
	[WebCastID] [uniqueidentifier] NOT NULL,
	[SessionID] [uniqueidentifier] NOT NULL,
	[CastName] [nvarchar](150) NULL
) ON [PRIMARY]

GO


--8)[InterruptMessagesReply]
CREATE TABLE [dbo].[InterruptMessagesReply]
(
	[MsgId] [uniqueidentifier] NOT NULL,
	[SessionId] [uniqueidentifier] NOT NULL,
	[CreatedDate] [datetime] NOT NULL,
	[Acknowledge] [smallint] NOT NULL,
	[Reply] [nvarchar](500)NULL,
	[AcknowledgeDate] [datetime] NULL,
	CONSTRAINT [PK_InterruptMessagesSessions] PRIMARY KEY 
	(
		[MsgId] ASC,
		[SessionId] ASC
	) ON [PRIMARY]
) ON [PRIMARY]

GO

--9)[InterruptMessagesLog]
CREATE TABLE [dbo].[InterruptMessagesLog]
(
	[LogId] [int] PRIMARY KEY,
	[MsgId] [uniqueidentifier] NOT NULL,
	[ServerId] [uniqueidentifier] NOT NULL,
	[MsgName] [nvarchar](100) NOT NULL,
	[MsgText] [nvarchar](500) NOT NULL,
	[PostedBy] [nvarchar](100) NOT NULL,
	[CreatedDate] [datetime] NOT NULL ,
	[Status] [int] NOT NULL,
	[ShowOnlyOneTime] [int] NOT NULL,
	[ExpirationDate] [datetime] NULL,
	[StartDate] [datetime] NOT NULL,
	[ModifiedDate] [datetime] NOT NULL,
	[SessionId] [uniqueidentifier] NOT NULL,
	[Acknowledge] [smallint] NOT NULL ,
	[Reply] [nvarchar](500) NOT NULL,
	[AcknowledgeDate] [datetime] NULL,
	[UserName] [nvarchar](50) NULL,
	[LoginName] [nvarchar](50) NOT NULL,
	[DomainName] [nvarchar](50)NOT NULL,
	[LogCreatedDate] [datetime] NOT NULL ,
	[IsActive] [smallint] NOT NULL
) ON [PRIMARY]

GO

--10)[ServerInstalledSoftware]
CREATE TABLE [dbo].[ServerInstalledSoftware]
(
	[SISID] [uniqueidentifier] PRIMARY KEY ,
	[SrvID] [uniqueidentifier] NOT NULL,
	[DisplayName] [nvarchar](200) NOT NULL,
	[SStatus] [smallint] NOT NULL ,
	[InstalldDate] [datetime] NULL,
	[AgentCreatedDate] [datetime] NULL,
	[SessionID] [uniqueidentifier] NOT NULL ,
	[UpdateStatus] [smallint] NOT NULL 
) ON [PRIMARY]

GO

--11)[ServerInstalledSoftwareHistory]
CREATE TABLE [dbo].[ServerInstalledSoftwareHistory](
	[SISID] [uniqueidentifier] NOT NULL,
	[SrvID] [uniqueidentifier] NOT NULL,
	[DisplayName] [nvarchar](200) NOT NULL,
	[SStatus] [smallint] NOT NULL ,
	[InstalldDate] [datetime] NULL,
	[AgentCreatedDate] [datetime] NULL ,
	[SessionID] [uniqueidentifier] NOT NULL ,
	[IsAgentInit] [tinyint] NULL 
) ON [PRIMARY]
GO


--12)[Screenshot]
CREATE TABLE [dbo].[Screenshot]
(
	[SSID] [uniqueidentifier] PRIMARY KEY,
	[SDateTime] [datetime] NOT NULL,
	[SBytes] [int] NULL,
	[SSessionID] [uniqueidentifier] NOT NULL,
	[SrvID] [uniqueidentifier] NOT NULL,
	[SComment] [nvarchar](500) NULL,
	[WindowTitle] [nvarchar](256) NULL,
	[WindowUniqueID] [varchar](256)NOT NULL ,
	[ProcessName] [varchar](256)NOT NULL,
	[ApplicationName] [nvarchar](256) NOT NULL,
	[WindowHandle] [int] NOT NULL ,
	[WindowRectangle] [varchar](60) NOT NULL ,
	[GroupId] [uniqueidentifier] NOT NULL ,
	[PrintScreenMode] [smallint] NOT NULL ,
	[ImageFormat] [smallint] NOT NULL ,
	[LinkPath] [nvarchar](600) NOT NULL ,
	[LinkFileName] [nvarchar](100) NOT NULL ,
	[EncryptionKeyId] [uniqueidentifier] NOT NULL ,
	[MetaDataHash] [varchar](80) NULL,
	[ImageHash] [varchar](80)  NULL,
	[WindowUrl] [nvarchar](600) NULL,
    [Screenshot] [IMAGE] NOT NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]

GO

--13)[Standardization]
CREATE TABLE [dbo].[Standardization]
(
	[STDID] [uniqueidentifier] PRIMARY KEY ,
	[SSID] [uniqueidentifier] NOT NULL,
	[WindowUniqueID] [varchar](256) NOT NULL,
	[SDescription] [nvarchar](1000) NULL,
	[CreateDate] [datetime] ,
) ON [PRIMARY]

GO

--14)[DictionaryScreenshots]
CREATE TABLE [dbo].[DictionaryScreenshots]
(
	[DictionaryItemId] [int] NOT NULL,
	[ScreenshotId] [uniqueidentifier] NOT NULL,
	[ScreenshotDate] [datetime] NOT NULL ,
	[ApplicationName] [nvarchar](256) NULL,
	[SessionId] [uniqueidentifier] NULL,
	CONSTRAINT [PK_DictionaryScreenshots] PRIMARY KEY CLUSTERED 
	(
		[DictionaryItemId] ASC,
		[ScreenshotId] ASC
	) ON [PRIMARY]
) ON [PRIMARY]

GO

--15)[ScreenshotText]
CREATE TABLE [dbo].[ScreenshotText]
(
	[ScreenshotId] [uniqueidentifier] PRIMARY KEY,
	[ActiveText] [nvarchar](2000) NULL,
) ON [PRIMARY]

GO

--16)[ScreenshotBookmarks]
CREATE TABLE [dbo].[ScreenshotBookmarks]
(
	[SSID] [uniqueidentifier] PRIMARY KEY,
	[BkmText] [varchar](300)  NOT NULL,
	[DateCreated] [datetime] NOT NULL
) ON [PRIMARY]

GO

--17)[CastsScreenshots]
CREATE TABLE [dbo].[CastsScreenshots]
(
	[SSID] [uniqueidentifier] NOT NULL,
	[CastID] [uniqueidentifier] NOT NULL,
	[SessionID] [uniqueidentifier] NOT NULL,
	[WebCastID] [uniqueidentifier] NOT NULL,
	[SComment] [nvarchar](500) NULL,
	CONSTRAINT [PK_CastsScreenshots] PRIMARY KEY CLUSTERED 
	(
		[SSID] ASC,
		[CastID] ASC
	) ON [PRIMARY]
) ON [PRIMARY]
GO


/****************************************************************************************/

CREATE PROC dbo.MoveToArchive
(
     @ArchiveAllDB BIT = 0
    ,@DateFrom DATETIME = '1900-01-01'
    ,@DateTo   DATETIME = '1900-01-01'
)
AS
BEGIN
    SET NOCOUNT ON

  -- SELECT @DateFrom = '2008-05-20',@DateTo = '2008-05-21'

	IF (@ArchiveAllDB = 1)
    BEGIN
		SELECT @DateTo = MAX (SDateTime) FROM ObserveIT.dbo.Screenshot
		SELECT @DateFrom = MIN (SDateTime) FROM ObserveIT.dbo.Screenshot
    END

    /*********** Get Archived Session Range   ***************************************************/

    CREATE TABLE #tempSessionList
    (
        SessionId UNIQUEIDENTIFIER
    )


    INSERT INTO #tempSessionList
    (
        SessionId 
    )
    SELECT DISTINCT SSessionID
      FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
     WHERE SDateTime BETWEEN @DateFrom AND @DateTo

     --select * FROM #tempSessionList


    -- Add servers that involved in the archived sessoins
    INSERT INTO ObserveIT_Archive.dbo.ServerInvatory
	SELECT DISTINCT SI.SrvID
		  ,SrvName
		  ,SrvDateTime
		  ,SrvVersion
		  ,SrvConfigurationStatus
		  ,SrvMonitorStatus
		  ,EncryptionKeyId
		  ,MetaDataHash
		  ,GroupPolicyId
		  ,MetaDataHashByLicense
		  ,AgentType
	  FROM ObserveIT.dbo.ServerInvatory SI
	  JOIN ObserveIT.dbo.ScreenshotsSessions SCS
        ON SCS.SrvID = SI.SrvID 
	 WHERE SCS.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SI.SrvID NOT IN (SELECT SrvID FROM ObserveIT_Archive.dbo.ServerInvatory WITH (NOLOCK))


     --select * FROM ObserveIT_Archive.dbo.ServerInvatory

     /*********** Insert into Archive database  **********************************************/

    --1) INSERT INTO ScreenshotsSessions
    INSERT INTO ObserveIT_Archive.dbo.ScreenshotsSessions
	SELECT SessionID
		  ,SrvID
		  ,LoginName
		  ,DomainName
		  ,MachineName
		  ,SessionDate
		  ,ClientAddress
		  ,ClientName
		  ,Trim
		  ,ExtSlides
		  ,SessionLastActivityDate
		  ,IsAlive
	  FROM ObserveIT.dbo.ScreenshotsSessions SCS
	 WHERE SCS.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SCS.SessionID NOT IN (SELECT SessionID FROM ObserveIT_Archive.dbo.ScreenshotsSessions WITH (NOLOCK))


    --2) INSERT INTO SessionDetails
    INSERT INTO ObserveIT_Archive.dbo.SessionDetails
	SELECT SDID
		  ,SessionID
		  ,UserName
		  ,Category
		  ,Description
		  ,SessionDate
		  ,WebCastID
		  ,WebCastName
		  ,UserAuthentication
	  FROM ObserveIT.dbo.SessionDetails SD
	 WHERE SD.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SD.SessionID NOT IN (SELECT SessionID FROM ObserveIT_Archive.dbo.SessionDetails WITH (NOLOCK))


	--3)[SessionProcesses]
    INSERT INTO ObserveIT_Archive.dbo.SessionProcesses
	SELECT SP.SessionId
		  ,SP.ProcessName
		  ,SP.ApplicationName
	  FROM ObserveIT.dbo.SessionProcesses SP
	  LEFT JOIN ObserveIT_Archive.dbo.SessionProcesses SP_A WITH (NOLOCK) 
        ON SP.SessionId = SP_A.SessionId 
	   AND SP.ProcessName = SP_A.ProcessName 	
	 WHERE SP.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SP_A.SessionId IS NULL
       AND SP_A.ProcessName IS NULL


	--4)[SessionProcessWindowTitles]
    INSERT INTO ObserveIT_Archive.dbo.SessionProcessWindowTitles
	SELECT SPWT.SessionId
		  ,SPWT.ProcessName
		  ,SPWT.WindowTitle
		  ,SPWT.ApplicationName
		  ,SPWT.FirstScreenshotId
		  ,SPWT.FirstScreenshotTime
	  FROM ObserveIT.dbo.SessionProcessWindowTitles SPWT
	  LEFT JOIN ObserveIT_Archive.dbo.SessionProcessWindowTitles SPWT_A WITH (NOLOCK) 
        ON SPWT.SessionId = SPWT_A.SessionId 
	   AND SPWT.ProcessName = SPWT_A.ProcessName 	
	   AND SPWT.WindowTitle = SPWT_A.WindowTitle 	
	 WHERE SPWT.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SPWT_A.SessionId IS NULL
       AND SPWT_A.ProcessName IS NULL
	   AND SPWT_A.WindowTitle IS NULL 	

	--5)[ClientSessionLog]
    INSERT INTO ObserveIT_Archive.dbo.ClientSessionLog
	SELECT SessionId
		  ,ServerId
		  ,MachineName
		  ,LoginName
		  ,DomainName
		  ,CreatedDate
		  ,Status
	  FROM ObserveIT.dbo.ClientSessionLog 
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SessionID NOT IN (SELECT SessionID FROM ObserveIT_Archive.dbo.ClientSessionLog WITH (NOLOCK))

	--6)[AuditLogSessions]
    INSERT INTO ObserveIT_Archive.dbo.AuditLogSessions
	SELECT AuditLogSessionId
		  ,AuditLogId
		  ,AccessedDate
		  ,SessionId
		  ,SessionLoginName
		  ,SessionDate
		  ,SessionServerName
	  FROM ObserveIT.dbo.AuditLogSessions 
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SessionID NOT IN (SELECT SessionID FROM ObserveIT_Archive.dbo.AuditLogSessions WITH (NOLOCK))


	--7)[Casts]
    INSERT INTO ObserveIT_Archive.dbo.Casts
	SELECT CastID
		  ,WebCastID
		  ,SessionID
		  ,CastName
	  FROM ObserveIT.dbo.Casts
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SessionID NOT IN (SELECT SessionID FROM ObserveIT_Archive.dbo.Casts WITH (NOLOCK))



	--8)[InterruptMessagesReply]
    INSERT INTO ObserveIT_Archive.dbo.InterruptMessagesReply
	SELECT IMR.MsgId
		  ,IMR.SessionId
		  ,IMR.CreatedDate
		  ,IMR.Acknowledge
		  ,IMR.Reply
		  ,IMR.AcknowledgeDate
	  FROM ObserveIT.dbo.InterruptMessagesReply IMR
	  LEFT JOIN ObserveIT_Archive.dbo.InterruptMessagesReply IMR_A WITH (NOLOCK) 
        ON IMR.MsgId = IMR_A.MsgId 
	   AND IMR.SessionId = IMR_A.SessionId 	
	 WHERE IMR.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND IMR_A.MsgId IS NULL
       AND IMR_A.SessionId IS NULL

	--9)[InterruptMessagesLog]
    INSERT INTO ObserveIT_Archive.dbo.InterruptMessagesLog
	SELECT LogId
		  ,MsgId
		  ,ServerId
		  ,MsgName
		  ,MsgText
		  ,PostedBy
		  ,CreatedDate
		  ,Status
		  ,ShowOnlyOneTime
		  ,ExpirationDate
		  ,StartDate
		  ,ModifiedDate
		  ,SessionId
		  ,Acknowledge
		  ,Reply
		  ,AcknowledgeDate
		  ,UserName
		  ,LoginName
		  ,DomainName
		  ,LogCreatedDate
		  ,IsActive
	  FROM ObserveIT.dbo.InterruptMessagesLog	  
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND LogId NOT IN (SELECT LogId FROM ObserveIT_Archive.dbo.InterruptMessagesLog WITH (NOLOCK))

	--10)[ServerInstalledSoftware]
	INSERT INTO ObserveIT_Archive.dbo.ServerInstalledSoftware
	SELECT SISID
		  ,SrvID
		  ,DisplayName
		  ,SStatus
		  ,InstalldDate
		  ,AgentCreatedDate
		  ,SessionID
		  ,UpdateStatus
	  FROM ObserveIT.dbo.ServerInstalledSoftware
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SISID NOT IN (SELECT SISID FROM ObserveIT_Archive.dbo.ServerInstalledSoftware WITH (NOLOCK))

	--11)[ServerInstalledSoftwareHistory]
	INSERT INTO ObserveIT_Archive.dbo.ServerInstalledSoftwareHistory
	SELECT SISID
		  ,SrvID
		  ,DisplayName
		  ,SStatus
		  ,InstalldDate
		  ,AgentCreatedDate
		  ,SessionID
		  ,IsAgentInit
	  FROM ObserveIT.dbo.ServerInstalledSoftwareHistory
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SISID NOT IN (SELECT SISID FROM ObserveIT_Archive.dbo.ServerInstalledSoftwareHistory WITH (NOLOCK))

    --12) INSERT INTO Screenshot
    INSERT INTO ObserveIT_Archive.dbo.Screenshot
    SELECT SD.SSID
		  ,SDateTime
		  ,SBytes
		  ,SSessionID
		  ,SrvID
		  ,SComment
		  ,WindowTitle
		  ,WindowUniqueID
		  ,ProcessName
		  ,ApplicationName
		  ,WindowHandle
		  ,WindowRectangle
		  ,GroupId
		  ,PrintScreenMode
		  ,ImageFormat
		  ,LinkPath
		  ,LinkFileName
		  ,EncryptionKeyId
		  ,MetaDataHash
		  ,ImageHash
		  ,WindowUrl
          ,SD.Screenshot 
      FROM ObserveIT.dbo.Screenshot SO 
      JOIN ObserveIT_Data.dbo.Screenshot SD ON (SO.SSID = SD.SSID)
     WHERE SD.SSID IN (SELECT SSID
                         FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                        WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SD.SSID NOT IN (SELECT SSID FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK))


	--13) INTO dbo.Standardization
    INSERT INTO ObserveIT_Archive.dbo.Standardization 
    (
        SSID
       ,WindowUniqueID
       ,SDescription
    )
	SELECT SSID
       ,WindowUniqueID
       ,SDescription
	  FROM ObserveIT.dbo.Standardization 
	 WHERE SSID IN (SELECT SSID
                      FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Archive.dbo.Standardization WITH (NOLOCK))


	--14)[DictionaryScreenshots]
    INSERT INTO ObserveIT_Archive.dbo.DictionaryScreenshots
    (
        DictionaryItemId
       ,ScreenshotId
       ,ApplicationName
       ,SessionId
    )
	SELECT DSS.DictionaryItemId
       ,DSS.ScreenshotId
       ,DSS.ApplicationName
       ,DSS.SessionId
	  FROM ObserveIT.dbo.DictionaryScreenshots DSS
	  LEFT JOIN ObserveIT_Archive.dbo.DictionaryScreenshots DSS_A WITH (NOLOCK) 
		ON DSS.DictionaryItemId = DSS_A.DictionaryItemId 
	   AND DSS.ScreenshotId = DSS_A.ScreenshotId 	
	 WHERE DSS.ScreenshotId IN (SELECT SSID
								  FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
								 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND DSS_A.DictionaryItemId IS NULL
	   AND DSS_A.ScreenshotId IS NULL

	--15)[ScreenshotText]
    INSERT INTO ObserveIT_Archive.dbo.ScreenshotText
    (
        ScreenshotId
       ,ActiveText
    )
	SELECT ScreenshotId
		  ,ActiveText
	  FROM ObserveIT.dbo.ScreenshotText 
	 WHERE ScreenshotId IN (SELECT SSID
						      FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
							 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND ScreenshotId NOT IN (SELECT ScreenshotId FROM ObserveIT_Archive.dbo.ScreenshotText WITH (NOLOCK))


	--16)[ScreenshotBookmarks]
	INSERT INTO ObserveIT_Archive.dbo.ScreenshotBookmarks 
	(
		 SSID
		,BkmText
	)
	SELECT SSID
		  ,BkmText
	  FROM ObserveIT.dbo.ScreenshotBookmarks 
	 WHERE SSID IN (SELECT SSID
                      FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Archive.dbo.ScreenshotBookmarks WITH (NOLOCK))

	
	--17)[CastsScreenshots]
    INSERT INTO ObserveIT_Archive.dbo.CastsScreenshots
	SELECT CSS.SSID
		  ,CSS.CastID
		  ,CSS.SessionID
		  ,CSS.WebCastID
		  ,CSS.SComment
	  FROM ObserveIT.dbo.CastsScreenshots CSS
	  LEFT JOIN ObserveIT_Archive.dbo.CastsScreenshots CSS_A WITH (NOLOCK) 
        ON CSS.SSID = CSS_A.SSID 
	   AND CSS.CastID = CSS_A.CastID 	
	 WHERE CSS.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND CSS_A.SSID IS NULL
       AND CSS_A.CastID IS NULL


    /*********** Delete from main database  **************************************************/
    -- Delete screenshots images    ----------------------------------------------------------	

    DELETE ObserveIT_Data.dbo.Screenshot_01
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
 
    DELETE ObserveIT_Data.dbo.Screenshot_02
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_03
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_04
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_05
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_06
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_07
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_08
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_09
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_10
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_11
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_12
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_13
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_14
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_15
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_16
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_17
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_18
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_19
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_20
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_21
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_22
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_23
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_24
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_25
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_26
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_27
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_28
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_29
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_30
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
    
    DELETE ObserveIT_Data.dbo.Screenshot_31
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))


    -- Delete MetaData ----------------------------------------------------------	

	--13)Standardization
    DELETE ObserveIT.dbo.Standardization
     WHERE SSID IN  (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))


	--14)DictionaryScreenshots
    DELETE ObserveIT.dbo.DictionaryScreenshots
		 WHERE ScreenshotId IN (SELECT SSID
                                  FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                                 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))

	--15)ScreenshotText
	   DELETE ObserveIT.dbo.ScreenshotText
		 WHERE ScreenshotId IN (SELECT SSID
                                  FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                                 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))


	--16)[ScreenshotBookmarks]
    DELETE ObserveIT.dbo.ScreenshotBookmarks
		 WHERE SSID IN (SELECT SSID
                          FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                         WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))

	--17)DELETE FROM [CastsScreenshots]
    DELETE FROM ObserveIT.dbo.CastsScreenshots
     WHERE SSID IN (SELECT SSID
                       FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                      WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))

    --12) DELETE FROM  Screenshot
    DELETE FROM ObserveIT.dbo.Screenshot
     WHERE SSID IN (SELECT SSID
                      FROM ObserveIT.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))


	--11)DELETE FROM [ServerInstalledSoftwareHistory]
	DELETE FROM ObserveIT.dbo.ServerInstalledSoftwareHistory
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--10)DELETE FROM [ServerInstalledSoftware]
	DELETE FROM  ObserveIT.dbo.ServerInstalledSoftware
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

	--9)DELETE FROM [InterruptMessagesLog]
    DELETE FROM ObserveIT.dbo.InterruptMessagesLog
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--8)DELETE FROM [InterruptMessagesReply]
    DELETE FROM ObserveIT.dbo.InterruptMessagesReply
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

	--7)DELETE FROM [Casts]
    DELETE FROM ObserveIT.dbo.Casts
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--6)DELETE FROM [ClientSessionLog]
    DELETE FROM ObserveIT.dbo.ClientSessionLog
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--5)DELETE FROM [AuditLogSessions]
    DELETE FROM ObserveIT.dbo.AuditLogSessions
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--4)DELETE FROM [SessionProcessWindowTitles]
    DELETE FROM ObserveIT.dbo.SessionProcessWindowTitles
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--3)DELETE FROM [SessionProcesses]
    DELETE FROM ObserveIT.dbo.SessionProcesses
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


    --2) DELETE FROM SessionDetails
    DELETE FROM ObserveIT.dbo.SessionDetails
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

    --1) DELETE FROM ScreenshotsSessions
    DELETE FROM  ObserveIT.dbo.ScreenshotsSessions
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

    DROP TABLE #tempSessionList   
    
    SET NOCOUNT OFF
END


GO

/**************	RESTORE ********************/

CREATE PROC dbo.MoveFromArchive
(
     @RestoreAllDB BIT = 0
    ,@DateFrom DATETIME = '1900-01-01'
    ,@DateTo   DATETIME = '1900-01-01'
)
AS
BEGIN
    SET NOCOUNT ON
 
	IF (@RestoreAllDB = 1)
    BEGIN
		SELECT @DateTo = MAX (SDateTime) FROM ObserveIT_Archive.dbo.Screenshot
		SELECT @DateFrom = MIN (SDateTime) FROM ObserveIT_Archive.dbo.Screenshot
    END

    /*********** Get Archived Session Range   ***************************************************/

    CREATE TABLE #tempSessionList
    (
        SessionId UNIQUEIDENTIFIER
    )


    /*
		Dependency : 
			1.ServerInvatory
	*/

    INSERT INTO #tempSessionList
    (
        SessionId 
    )
    SELECT DISTINCT SSessionID
      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
     WHERE SDateTime BETWEEN @DateFrom AND @DateTo
       AND SrvID IN (SELECT SrvID
                       FROM ObserveIT.dbo.ServerInvatory WITH (NOLOCK))


     select * FROM #tempSessionList


     /*********** Restore from Archive database to observeit  **********************************************/

    --1) INSERT INTO ScreenshotsSessions
    INSERT INTO ObserveIT.dbo.ScreenshotsSessions
	SELECT SessionID
		  ,SrvID
		  ,LoginName
		  ,DomainName
		  ,MachineName
		  ,SessionDate
		  ,ClientAddress
		  ,ClientName
		  ,Trim
		  ,ExtSlides
		  ,SessionLastActivityDate
		  ,IsAlive
	  FROM ObserveIT_Archive.dbo.ScreenshotsSessions SCS
	 WHERE SCS.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SCS.SessionID NOT IN (SELECT SessionID FROM ObserveIT.dbo.ScreenshotsSessions WITH (NOLOCK))


    --2) INSERT INTO SessionDetails
        /*
			Dependency :NONE 
		*/
    INSERT INTO ObserveIT.dbo.SessionDetails
	SELECT SDID
		  ,SessionID
		  ,UserName
		  ,Category
		  ,Description
		  ,SessionDate
		  ,WebCastID
		  ,WebCastName
		  ,UserAuthentication
	  FROM ObserveIT_Archive.dbo.SessionDetails 
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SessionID NOT IN (SELECT SessionID FROM ObserveIT.dbo.SessionDetails WITH (NOLOCK))


	--3)[SessionProcesses]
        /*
			Dependency : 
				1.Application ?
		*/
    INSERT INTO ObserveIT.dbo.SessionProcesses
	SELECT SP_A.SessionId
		  ,SP_A.ProcessName
		  ,SP_A.ApplicationName
	  FROM ObserveIT_Archive.dbo.SessionProcesses SP_A
	  LEFT JOIN ObserveIT.dbo.SessionProcesses SP WITH (NOLOCK) 
        ON SP_A.SessionId = SP.SessionId 
	   AND SP_A.ProcessName = SP.ProcessName 	
	 WHERE SP_A.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SP.SessionId IS NULL
       AND SP.ProcessName IS NULL


	--4)[SessionProcessWindowTitles]
        /*
			Dependency :NONE 
		*/
    INSERT INTO ObserveIT.dbo.SessionProcessWindowTitles
	SELECT SPWT_A.SessionId
		  ,SPWT_A.ProcessName
		  ,SPWT_A.WindowTitle
		  ,SPWT_A.ApplicationName
		  ,SPWT_A.FirstScreenshotId
		  ,SPWT_A.FirstScreenshotTime
	  FROM ObserveIT_Archive.dbo.SessionProcessWindowTitles SPWT_A 
	  LEFT JOIN ObserveIT.dbo.SessionProcessWindowTitles SPWT WITH (NOLOCK) 
        ON SPWT_A.SessionId = SPWT.SessionId 
	   AND SPWT_A.ProcessName = SPWT.ProcessName 	
	   AND SPWT_A.WindowTitle = SPWT.WindowTitle 	
	 WHERE SPWT_A.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SPWT.SessionId IS NULL
       AND SPWT.ProcessName IS NULL
	   AND SPWT.WindowTitle IS NULL 	

	--5)[AuditLogSessions]
	SET IDENTITY_INSERT ObserveIT.dbo.AuditLogSessions ON

    INSERT INTO ObserveIT.dbo.AuditLogSessions
	(
		   AuditLogSessionId
		  ,AuditLogId
		  ,AccessedDate
		  ,SessionId
		  ,SessionLoginName
		  ,SessionDate
		  ,SessionServerName
	)
	SELECT AuditLogSessionId
		  ,AuditLogId
		  ,AccessedDate
		  ,SessionId
		  ,SessionLoginName
		  ,SessionDate
		  ,SessionServerName
	  FROM ObserveIT_Archive.dbo.AuditLogSessions 
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SessionID NOT IN (SELECT SessionID FROM ObserveIT.dbo.AuditLogSessions WITH (NOLOCK))

	SET IDENTITY_INSERT ObserveIT.dbo.AuditLogSessions OFF 

	--6)[ClientSessionLog]
    INSERT INTO ObserveIT.dbo.ClientSessionLog
	SELECT SessionId
		  ,ServerId
		  ,MachineName
		  ,LoginName
		  ,DomainName
		  ,CreatedDate
		  ,Status
	  FROM ObserveIT_Archive.dbo.ClientSessionLog 
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SessionID NOT IN (SELECT SessionID FROM ObserveIT.dbo.ClientSessionLog WITH (NOLOCK))


	--7)[Casts]
    INSERT INTO ObserveIT.dbo.Casts
	SELECT CastID
		  ,WebCastID
		  ,SessionID
		  ,CastName
	  FROM ObserveIT_Archive.dbo.Casts
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SessionID NOT IN (SELECT SessionID FROM ObserveIT.dbo.Casts WITH (NOLOCK))


	--8)[InterruptMessagesReply]
    INSERT INTO ObserveIT.dbo.InterruptMessagesReply
	SELECT IMR_A.MsgId
		  ,IMR_A.SessionId
		  ,IMR_A.CreatedDate
		  ,IMR_A.Acknowledge
		  ,IMR_A.Reply
		  ,IMR_A.AcknowledgeDate
	  FROM ObserveIT_Archive.dbo.InterruptMessagesReply IMR_A
	  LEFT JOIN ObserveIT.dbo.InterruptMessagesReply IMR WITH (NOLOCK) 
        ON IMR_A.MsgId = IMR.MsgId 
	   AND IMR_A.SessionId = IMR.SessionId 	
	 WHERE IMR_A.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND IMR.MsgId IS NULL
       AND IMR.SessionId IS NULL
       AND IMR_A.MsgId IN (SELECT MsgId FROM ObserveIT.dbo.InterruptMessages  WITH (NOLOCK))

	--9)[InterruptMessagesLog]
	SET IDENTITY_INSERT ObserveIT.dbo.InterruptMessagesLog ON

    INSERT INTO ObserveIT.dbo.InterruptMessagesLog
    (
		   LogId
		  ,MsgId
		  ,ServerId
		  ,MsgName
		  ,MsgText
		  ,PostedBy
		  ,CreatedDate
		  ,Status
		  ,ShowOnlyOneTime
		  ,ExpirationDate
		  ,StartDate
		  ,ModifiedDate
		  ,SessionId
		  ,Acknowledge
		  ,Reply
		  ,AcknowledgeDate
		  ,UserName
		  ,LoginName
		  ,DomainName
		  ,LogCreatedDate
		  ,IsActive
    )
	SELECT LogId
		  ,MsgId
		  ,ServerId
		  ,MsgName
		  ,MsgText
		  ,PostedBy
		  ,CreatedDate
		  ,Status
		  ,ShowOnlyOneTime
		  ,ExpirationDate
		  ,StartDate
		  ,ModifiedDate
		  ,SessionId
		  ,Acknowledge
		  ,Reply
		  ,AcknowledgeDate
		  ,UserName
		  ,LoginName
		  ,DomainName
		  ,LogCreatedDate
		  ,IsActive
	  FROM ObserveIT_Archive.dbo.InterruptMessagesLog	  
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND LogId NOT IN (SELECT LogId FROM ObserveIT.dbo.InterruptMessagesLog WITH (NOLOCK))
       AND MsgId IN (SELECT MsgId FROM ObserveIT.dbo.InterruptMessages  WITH (NOLOCK))

	SET IDENTITY_INSERT ObserveIT.dbo.InterruptMessagesLog OFF


	--10)[ServerInstalledSoftware]
	INSERT INTO ObserveIT.dbo.ServerInstalledSoftware
	SELECT SISID
		  ,SrvID
		  ,DisplayName
		  ,SStatus
		  ,InstalldDate
		  ,AgentCreatedDate
		  ,SessionID
		  ,UpdateStatus
	  FROM ObserveIT_Archive.dbo.ServerInstalledSoftware
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SISID NOT IN (SELECT SISID FROM ObserveIT.dbo.ServerInstalledSoftware WITH (NOLOCK))

	--11)[ServerInstalledSoftwareHistory]
	INSERT INTO ObserveIT.dbo.ServerInstalledSoftwareHistory
	SELECT SISID
		  ,SrvID
		  ,DisplayName
		  ,SStatus
		  ,InstalldDate
		  ,AgentCreatedDate
		  ,SessionID
		  ,IsAgentInit
	  FROM ObserveIT_Archive.dbo.ServerInstalledSoftwareHistory
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND SISID NOT IN (SELECT SISID FROM ObserveIT.dbo.ServerInstalledSoftwareHistory WITH (NOLOCK))


    --12) INSERT INTO Screenshot
        /*
			Dependency :NONE 
		*/
    INSERT INTO ObserveIT.dbo.Screenshot
    SELECT SSID
          ,NULL
		  ,SDateTime
		  ,SBytes
		  ,SSessionID
		  ,SrvID
		  ,SComment
		  ,WindowTitle
		  ,WindowUniqueID
		  ,ProcessName
		  ,ApplicationName
		  ,WindowHandle
		  ,WindowRectangle
		  ,GroupId
		  ,PrintScreenMode
		  ,ImageFormat
		  ,LinkPath
		  ,LinkFileName
		  ,EncryptionKeyId
		  ,MetaDataHash
		  ,ImageHash
		  ,WindowUrl
      FROM ObserveIT_Archive.dbo.Screenshot  
     WHERE SSID IN (SELECT SSID
                         FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                        WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT.dbo.Screenshot WITH (NOLOCK))


	--13) INTO dbo.Standardization
    INSERT INTO ObserveIT.dbo.Standardization 
    (
        SSID
       ,WindowUniqueID
       ,SDescription
    )
	SELECT SSID
       ,WindowUniqueID
       ,SDescription
	  FROM ObserveIT_Archive.dbo.Standardization 
	 WHERE SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT.dbo.Standardization WITH (NOLOCK))


	--14)[DictionaryScreenshots]
    INSERT INTO ObserveIT.dbo.DictionaryScreenshots
    (
        DictionaryItemId
       ,ScreenshotId
       ,ApplicationName
       ,SessionId
    )
	SELECT DSS_A.DictionaryItemId
       ,DSS_A.ScreenshotId
       ,DSS_A.ApplicationName
       ,DSS_A.SessionId
	  FROM ObserveIT_Archive.dbo.DictionaryScreenshots DSS_A
	  LEFT JOIN ObserveIT.dbo.DictionaryScreenshots DSS WITH (NOLOCK) 
		ON DSS_A.DictionaryItemId = DSS.DictionaryItemId 
	   AND DSS_A.ScreenshotId = DSS.ScreenshotId 	
	 WHERE DSS_A.ScreenshotId IN (SELECT SSID
								  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
								 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND DSS.DictionaryItemId IS NULL
	   AND DSS.ScreenshotId IS NULL
	   AND DSS_A.DictionaryItemId IN (SELECT DictionaryItemId FROM ObserveIT.dbo.Dictionary WITH (NOLOCK))


	--15)[ScreenshotText]
    INSERT INTO ObserveIT.dbo.ScreenshotText
    (
        ScreenshotId
       ,ActiveText
    )
	SELECT ScreenshotId
		  ,ActiveText
	  FROM ObserveIT_Archive.dbo.ScreenshotText 
	 WHERE ScreenshotId IN (SELECT SSID
						      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
							 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND ScreenshotId NOT IN (SELECT ScreenshotId FROM ObserveIT.dbo.ScreenshotText WITH (NOLOCK))


	--16)[ScreenshotBookmarks]
	INSERT INTO ObserveIT.dbo.ScreenshotBookmarks 
	(
		 SSID
		,BkmText
	)
	SELECT SSID
		  ,BkmText
	  FROM ObserveIT_Archive.dbo.ScreenshotBookmarks 
	 WHERE SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT.dbo.ScreenshotBookmarks WITH (NOLOCK))

	--17)[CastsScreenshots]
    INSERT INTO ObserveIT.dbo.CastsScreenshots
	SELECT CSS_A.SSID
		  ,CSS_A.CastID
		  ,CSS_A.SessionID
		  ,CSS_A.WebCastID
		  ,CSS_A.SComment
	  FROM ObserveIT_Archive.dbo.CastsScreenshots CSS_A
	  LEFT JOIN ObserveIT.dbo.CastsScreenshots CSS WITH (NOLOCK) 
        ON CSS_A.SSID = CSS.SSID 
	   AND CSS_A.CastID = CSS.CastID 	
	 WHERE CSS_A.SessionID IN (SELECT SessionId FROM #tempSessionList)
	   AND CSS.SSID IS NULL
       AND CSS.CastID IS NULL
       AND CSS_A.CastID IN (SELECT CastID FROM ObserveIT.dbo.Casts  WITH (NOLOCK))




    /*********** Delete from main database  **************************************************/
    -- INSERT screenshots images    ----------------------------------------------------------	

    INSERT INTO ObserveIT_Data.dbo.Screenshot_01
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot 
     WHERE DAY(SDateTime) = 1
       AND SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
       AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_01 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_02
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 2
      AND SSID IN (SELECT SSID
                     FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                    WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
      AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_02 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_03
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 3
      AND SSID IN (SELECT SSID
                     FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                    WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
      AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_03 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_04
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 4
       AND SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
       AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_04 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_05
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 5
	   AND SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
       AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_05 WITH (NOLOCK))



    INSERT INTO ObserveIT_Data.dbo.Screenshot_06
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 6
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_06 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_07
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 7
	   AND SSID IN (SELECT SSID
						 FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
						WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_07 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_08
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 8
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_08 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_09
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 9
	   AND SSID IN (SELECT SSID
						 FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
						WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_09 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_10
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 10
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_10 WITH (NOLOCK))

    INSERT INTO ObserveIT_Data.dbo.Screenshot_11
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 11
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_11 WITH (NOLOCK))

    INSERT INTO ObserveIT_Data.dbo.Screenshot_12
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 12
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_12 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_13
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 13
	   AND SSID IN (SELECT SSID
				  	  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_13 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_14
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 14
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_14 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_15
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 15
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_15 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_16
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 16
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_16 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_17
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 17
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_17 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_18
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 18
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID	 FROM ObserveIT_Data.dbo.Screenshot_18 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_19
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 19
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_19 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_20
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 20
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_20 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_21
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 21
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_21 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_22
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 22
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_22 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_23
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 23
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_23 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_24
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 24
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_24 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_25
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 25
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_25 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_26
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 26
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_26 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_27
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 27
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_27 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_28
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 28
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_28 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_29
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 29
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_29 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_30
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 30
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_30 WITH (NOLOCK))


    INSERT INTO ObserveIT_Data.dbo.Screenshot_31
    SELECT SSID, Screenshot 
      FROM ObserveIT_Archive.dbo.Screenshot
     WHERE DAY(SDateTime) = 31
	   AND SSID IN (SELECT SSID
					  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
					 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))
	   AND SSID NOT IN (SELECT SSID FROM ObserveIT_Data.dbo.Screenshot_31 WITH (NOLOCK))



 
    -- Delete MetaData ----------------------------------------------------------	
	--13)Standardization
    DELETE ObserveIT_Archive.dbo.Standardization
     WHERE SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))


	--14)[DictionaryScreenshots]
    DELETE ObserveIT_Archive.dbo.DictionaryScreenshots
     WHERE ScreenshotId IN (SELECT SSID
                              FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                             WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))

	--15)[ScreenshotText]
    DELETE ObserveIT_Archive.dbo.ScreenshotText
	 WHERE ScreenshotId IN (SELECT SSID
							  FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
							 WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))


	--16)[ScreenshotBookmarks]
    DELETE ObserveIT_Archive.dbo.ScreenshotBookmarks
     WHERE SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))

	--17)DELETE FROM [CastsScreenshots]
    DELETE FROM ObserveIT_Archive.dbo.CastsScreenshots
     WHERE SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))

    --12) DELETE FROM  Screenshot
    DELETE FROM ObserveIT_Archive.dbo.Screenshot
     WHERE SSID IN (SELECT SSID
                      FROM ObserveIT_Archive.dbo.Screenshot WITH (NOLOCK)
                     WHERE SSessionID IN (SELECT SessionId FROM #tempSessionList))


	--11)DELETE FROM [ServerInstalledSoftwareHistory]
	DELETE FROM ObserveIT_Archive.dbo.ServerInstalledSoftwareHistory
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--10)DELETE FROM [ServerInstalledSoftware]
	DELETE FROM  ObserveIT_Archive.dbo.ServerInstalledSoftware
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

	--9)DELETE FROM [InterruptMessagesLog]
    DELETE FROM ObserveIT_Archive.dbo.InterruptMessagesLog
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--8)DELETE FROM [InterruptMessagesReply]
    DELETE FROM ObserveIT_Archive.dbo.InterruptMessagesReply
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

	--7)DELETE FROM [Casts]
    DELETE FROM ObserveIT_Archive.dbo.Casts
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

	--6)DELETE FROM [ClientSessionLog]
    DELETE FROM ObserveIT_Archive.dbo.ClientSessionLog
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--5)DELETE FROM [AuditLogSessions]
    DELETE FROM ObserveIT_Archive.dbo.AuditLogSessions
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--4)DELETE FROM [SessionProcessWindowTitles]
    DELETE FROM ObserveIT_Archive.dbo.SessionProcessWindowTitles
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


	--3)DELETE FROM [SessionProcesses]
    DELETE FROM ObserveIT_Archive.dbo.SessionProcesses
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)


    --2) DELETE FROM SessionDetails
    DELETE FROM ObserveIT_Archive.dbo.SessionDetails
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

    --1) DELETE FROM ScreenshotsSessions
    DELETE FROM ObserveIT_Archive.dbo.ScreenshotsSessions
	 WHERE SessionID IN (SELECT SessionId FROM #tempSessionList)

    DROP TABLE #tempSessionList   
    
    SET NOCOUNT OFF
END

GO